@@ -1,5 +1,3 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 4 -*- */
-
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
 
@@ -25,6 +23,7 @@
 #define __GLIBTOP_OPEN_H__
 
 #include <glibtop.h>
+#include <glibtop/read.h>
 #include <glibtop/error.h>
 
 BEGIN_LIBGTOP_DECLS
@@ -53,7 +52,7 @@ BEGIN_LIBGTOP_DECLS
 #define GLIBTOP_ERROR_METHOD_DEFAULT	GLIBTOP_ERROR_METHOD_WARN_ONCE
 
 void
-glibtop_open_l (glibtop *server, const char *backend_name,
+glibtop_open_l (glibtop *server, const char *program_name,
 		const unsigned long features, const unsigned flags);
 
 void
@@ -68,13 +67,6 @@ void
 glibtop_open_s (glibtop *server, const char *program_name,
 		const unsigned long features, const unsigned flags);
 
-#ifdef _IN_LIBGTOP
-
-void
-_glibtop_open_sysdeps (glibtop *server, const char *program_name,
-		       const unsigned long features, const unsigned flags);
-
-#endif /* _IN_LIBGTOP */
 
 END_LIBGTOP_DECLS
 
